export class AuroCalendarCell extends LitElement {
    static get properties(): {
        day: {
            type: ObjectConstructor;
        };
        selected: {
            type: BooleanConstructor;
        };
        hovered: {
            type: BooleanConstructor;
        };
        dateTo: {
            type: StringConstructor;
        };
        dateFrom: {
            type: StringConstructor;
        };
        month: {
            type: StringConstructor;
        };
        min: {
            type: NumberConstructor;
        };
        max: {
            type: NumberConstructor;
        };
        disabled: {
            type: BooleanConstructor;
        };
        disabledDays: {
            type: ArrayConstructor;
        };
        hoveredDate: {
            type: StringConstructor;
        };
        isCurrentDate: {
            type: BooleanConstructor;
        };
        locale: {
            type: ObjectConstructor;
        };
        dateStr: {
            type: StringConstructor;
        };
        renderForDateSlot: {
            type: BooleanConstructor;
        };
    };
    static get styles(): import("lit").CSSResult[];
    day: any;
    selected: boolean;
    hovered: boolean;
    dateTo: any;
    dateFrom: any;
    month: any;
    min: any;
    max: any;
    disabled: boolean;
    disabledDays: any[];
    hoveredDate: any;
    isCurrentDate: boolean;
    _locale: any;
    dateStr: string;
    renderForDateSlot: boolean;
    runtimeUtils: any;
    popoverTag: any;
    set locale(value: any);
    get locale(): any;
    /**
     * Handles selected and hovered states of the calendar cell when the date changes.
     * @private
     * @param {Number} dateFrom - Depart date.
     * @param {Number} dateTo - Return date.
     * @param {Number} hoveredDate - Hovered date.
     * @param {Object} day - An object containing the dateFrom and day of month values.
     * @returns {void}
     */
    private dateChanged;
    /**
     * Handles user click events and calls datepicker to update the value(s).
     * @private
     * @returns {void}
     */
    private handleTap;
    /**
     * Handles user hover events and dispatches a custom event.
     * @private
     * @returns {void}
     */
    private handleHover;
    /**
     * Checks if the current date is a valid date depending on the min and max values.
     * @private
     * @param {Object} day - An object containing the dateFrom and day of month values.
     * @param {Number} min - The minimum date value.
     * @param {Number} max - The maximum date value.
     * @param {Array} disabledDays - An array of disabled dates.
     * @returns {Boolean} - True if the date is disabled.
     */
    private isEnabled;
    /**
     * Checks if the current date is the depart date.
     * @private
     * @param {Object} day - An object containing the dateFrom and day of month values.
     * @param {Number} dateFrom - Depart date.
     * @returns {Boolean} True if the date is the depart date.
     */
    private isDepartDate;
    /**
     * Checks if the current date is the return date.
     * @private
     * @param {Object} day - An object containing the dateFrom and day of month values.
     * @param {Number} dateFrom - Depart date.
     * @param {Number} dateTo - Return date.
     * @returns {Boolean} True if the date is the return date.
     */
    private isReturnDate;
    /**
     * Checks if the current date is between dateFrom and dateTo.
     * @private
     * @param {Object} day - An object containing the dateFrom and day of month values.
     * @param {Number} dateFrom - Depart date.
     * @param {Number} dateTo - Return date.
     * @returns {Boolean} True if the current date is between dateFrom and dateTo.
     */
    private isInRange;
    /**
     * Determines the hovered date appearing latest in the calendar.
     * @private
     * @param {Object} day - An object containing the dateFrom and day of month values.
     * @param {Number} dateFrom - Depart date.
     * @param {Number} dateTo - Return date.
     * @param {Number} hoveredDate - Hovered date.
     * @returns {Boolean} True if the hovered date is the latest hovered date in the calendar.
     */
    private isLastHoveredDate;
    /**
     * Determines the title of the auro-calendar-cell.
     * @private
     * @param {Number} date - The date of the auro-calendar-cell.
     * @returns {String} The title of the auro-calendar-cell in the user's locale.
     */
    private getTitle;
    /**
     * Gets the name of the date slot.
     * @private
     * @returns {void}
     */
    private setDateSlotName;
    /**
     * Remove existing cell slot content and clone any current slot content from the root `auro-datepicker` which matches this cells date.
     * @private
     * @returns {void}
     */
    private handleSlotContent;
    firstUpdated(): void;
    datepicker: any;
    calendarMonth: any;
    auroPopover: any;
    updated(properties: any): void;
    render(): import("lit-html").TemplateResult;
}
import { LitElement } from "lit";
//# sourceMappingURL=auro-calendar-cell.d.ts.map