/**
 * @prop {Object} firstDayOfWeek - Weekday that will be displayed in first column of month grid.
 * 0: sunday, 1: monday, 2: tuesday, 3: wednesday , 4: thursday, 5: friday, 6: saturday
 * Default is 0.
 * @prop {Date | null} focusedDate - The currently focused date (if any).
 * @prop {Date} maxDate - Maximum date. All dates after will be disabled.
 * @prop {Date} minDate - Minimum date. All dates before will be disabled.
 * @prop {Date | undefined} selectedDate - The selected date, usually synchronized with datepicker-input.
 * Not to be confused with the focused date (therefore not necessarily in active month view).
 * @prop {string} weekdayHeaderNotation - Weekday header notation, based on Intl DatetimeFormat:
 * - 'short' (e.g., Thu)
 * - 'narrow' (e.g., T).
 * Default is 'short'.
 * @event auroCalendar-dateSelected - Notifies that a date has been selected in the calendar.
 * @event auroCalendar-ready - Notifies that the component has finished initializing.
 * @event auroCalendar-monthChanged - Notifies that the visible calendar month(s) have changed.
 */
export class AuroCalendar extends RangeDatepicker {
    static get styles(): import("lit").CSSResult[];
    static get properties(): {
        numCalendars: {
            type: NumberConstructor;
        };
        dateFrom: {
            type: StringConstructor;
        };
        dateTo: {
            type: StringConstructor;
        };
        maxDate: {
            type: StringConstructor;
            reflect: boolean;
        };
        minDate: {
            type: StringConstructor;
            reflect: boolean;
        };
        calendarStartMonth: {
            type: StringConstructor;
            reflect: boolean;
        };
        calendarEndMonth: {
            type: StringConstructor;
            reflect: boolean;
        };
        centralDate: {
            type: StringConstructor;
            reflect: boolean;
        };
    };
    /**
     * @private
     */
    private runtimeUtils;
    /**
     * @private
     */
    private util;
    /**
     * @private
     */
    private utilCal;
    /**
     * @private
     */
    private utilCalRender;
    datepicker: any;
    calendarStartDate: any;
    calendarEndDate: any;
    centralDate: any;
    showPrevMonthBtn: boolean;
    showNextMonthBtn: boolean;
    /**
     * @private
     */
    private firstMonthRenderable;
    /**
     * @private
     */
    private calendarRangeMonths;
    /**
     * @private
     */
    private numCalendars;
    /**
     * @private
     */
    private mobileBreakpoint;
    /**
     * Renders all of the auro-calendar-months HTML.
     * @private
     * @returns {Object} Returns the auro-calendar-months HTML.
     */
    private renderAllCalendars;
    firstRenderedMonth: any;
    /**
     * Request the calendar be scrolled to a given date.
     * @param {String} date - The date to scroll into view.
     * @returns {void}
     */
    scrollMonthIntoView(date: string): void;
}
import { RangeDatepicker } from './../vendor/wc-range-datepicker/range-datepicker.js';
//# sourceMappingURL=auro-calendar.d.ts.map